==> iReport-nb-3.1.0-src.zip: iReport-nb-3.1.0-src/ireport-designer/src/com/jaspersoft/ireport/designer/sheet/properties/charts/PlotForegroundAlphaProperty.java <==
/*
 * GraphicElementPropertiesFactory.java
 * 
 * Created on 5-nov-2007, 19.43.44
 * 
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package com.jaspersoft.ireport.designer.sheet.properties.charts;

import com.jaspersoft.ireport.designer.sheet.properties.FloatProperty;
import net.sf.jasperreports.engine.base.JRBaseChartPlot;
    
    
/**
 *  Class to manage the JRBaseChartPlot.PROPERTY_FOREGROUND_ALPHA property
 */
public final class PlotForegroundAlphaProperty extends FloatProperty {

    private final JRBaseChartPlot plot;

    @SuppressWarnings("unchecked")
    public PlotForegroundAlphaProperty(JRBaseChartPlot plot)
    {
        super(plot);
        this.plot = plot;
    }

    @Override
    public String getName()
    {
        return JRBaseChartPlot.PROPERTY_FOREGROUND_ALPHA;
    }

    @Override
    public String getDisplayName()
    {
        return "Foreground Alpha (%)";
    }

    @Override
    public String getShortDescription()
    {
        return "Foreground Alpha.";
    }

    @Override
    public Float getFloat()
    {
        return plot.getForegroundAlpha();
    }

    @Override
    public Float getOwnFloat()
    {
        return plot.getForegroundAlpha();
    }

    @Override
    public Float getDefaultFloat()
    {
        return 1f;
    }

    @Override
    public void setFloat(Float foregroundAlpha)
    {
        plot.setForegroundAlpha(foregroundAlpha);
    }

    @Override
    public void validateFloat(Float foregroundAlpha)
    {
        if (foregroundAlpha < 0f || foregroundAlpha > 1f)
        {
            throw annotateException("The value must be between 0 and 1.");
        }
    }

}

==> iReport-nb-3.1.3-src.zip: iReport-nb-3.1.3-src/ireport-designer/src/com/jaspersoft/ireport/designer/sheet/properties/charts/PlotForegroundAlphaProperty.java <==
/*
 * GraphicElementPropertiesFactory.java
 * 
 * Created on 5-nov-2007, 19.43.44
 * 
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package com.jaspersoft.ireport.designer.sheet.properties.charts;

import com.jaspersoft.ireport.designer.sheet.properties.FloatProperty;
import com.jaspersoft.ireport.locale.I18n;
import net.sf.jasperreports.engine.base.JRBaseChartPlot;
    
    
/**
 *  Class to manage the JRBaseChartPlot.PROPERTY_FOREGROUND_ALPHA property
 */
public final class PlotForegroundAlphaProperty extends FloatProperty {

    private final JRBaseChartPlot plot;

    
    public PlotForegroundAlphaProperty(JRBaseChartPlot plot)
    {
        super(plot);
        this.plot = plot;
    }

    @Override
    public String getName()
    {
        return JRBaseChartPlot.PROPERTY_FOREGROUND_ALPHA;
    }

    @Override
    public String getDisplayName()
    {
        return I18n.getString("Foreground_Alpha_(%)");
    }

    @Override
    public String getShortDescription()
    {
        return I18n.getString("Foreground_Alpha.");
    }

    @Override
    public Float getFloat()
    {
        return plot.getForegroundAlpha();
    }

    @Override
    public Float getOwnFloat()
    {
        return plot.getForegroundAlpha();
    }

    @Override
    public Float getDefaultFloat()
    {
        return 1f;
    }

    @Override
    public void setFloat(Float foregroundAlpha)
    {
        plot.setForegroundAlpha(foregroundAlpha);
    }

    @Override
    public void validateFloat(Float foregroundAlpha)
    {
        if (foregroundAlpha < 0f || foregroundAlpha > 1f)
        {
            throw annotateException(I18n.getString("The_value_must_be_between_0_and_1."));
        }
    }

}
